pub(crate) fn foundry_toml_dir_entries(
root: impl AsRef<Path>,
) -> Vec<FoundryTomlDir>Expand description
Returns depth-one dependency entries that resolve to directories containing foundry.toml.
pub(crate) fn foundry_toml_dir_entries(
root: impl AsRef<Path>,
) -> Vec<FoundryTomlDir>Returns depth-one dependency entries that resolve to directories containing foundry.toml.